@@ -27,16 +27,10 @@
 #include <KLocalizedString>
 #include <KAboutData>
 
-#include <QDebug>
-#include <QFileInfo>
-#include <QDir>
-#include <QStandardPaths>
-#include <QQuickView>
-#include <QQmlEngine>
-#include <QQmlContext>
-#include <QQmlApplicationEngine>
 #include <QCommandLineParser>
-#include <QIcon>
+#include <QQmlApplicationEngine>
+#include <QQmlContext>
+#include <QStandardPaths>
 
 #include "kalgebramobile.h"
 #include "kalgebra_version.h"
@@ -46,7 +40,9 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 #ifdef Q_OS_ANDROID
     QQuickStyle::setStyle("Material");
 #endif
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+#endif
 #ifdef Q_OS_ANDROID
     QGuiApplication app(argc, argv);
 #else
@@ -55,7 +51,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     KLocalizedString::setApplicationDomain("kalgebramobile");
     KAboutData about(QStringLiteral("kalgebramobile"), QStringLiteral("KAlgebra"), QStringLiteral(KALGEBRA_VERSION_STRING), i18n("A portable calculator"),
              KAboutLicense::GPL, i18n("(C) 2006-2020 Aleix Pol i Gonzalez"));
-    about.addAuthor( QStringLiteral("Aleix Pol i Gonzalez"), QString(), QStringLiteral("aleixpol@kde.org") );
+    about.addAuthor(i18n("Aleix Pol i Gonzalez"), QString(), QStringLiteral("aleixpol@kde.org"));
     about.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
     KAboutData::setApplicationData(about);
 
