@@ -29,7 +29,7 @@ int main(int argc, char *argv[])
     KLocalizedString::setApplicationDomain("kalgebra");
     KAboutData about(QStringLiteral("kalgebra"), QStringLiteral("KAlgebra"), QStringLiteral(KALGEBRA_VERSION_STRING), i18n("A portable calculator"),
              KAboutLicense::GPL, i18n("(C) 2006-2016 Aleix Pol i Gonzalez"));
-    about.addAuthor( QStringLiteral("Aleix Pol i Gonzalez"), QString(), QStringLiteral("aleixpol@kde.org") );
+    about.addAuthor(i18n("Aleix Pol i Gonzalez"), QString(), QStringLiteral("aleixpol@kde.org"));
     about.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
     KAboutData::setApplicationData(about);
 
